@@ -3,9 +3,9 @@ from collections import defaultdict
 import click
 import immutables
 
-from ..helpers.config import Config
-from ..helpers.config.config import ConfigSchema
-from ..helpers.validations import validate_resource
+from sym.cli.helpers.config import Config, ConfigSchema
+from sym.cli.helpers.validations import validate_resource
+
 from .sym import sym
 
 NO_VALIDATION = lambda _: True
@@ -16,7 +16,7 @@ VALIDATIONS = defaultdict(
 
 def key_callback(ctx, key: str):
     if key not in ConfigSchema.__annotations__:
-        raise click.BadParameter(key)
+        raise click.BadParameter(f"Unrecognized configuration key `{key}`")
     return key
 
 
@@ -24,7 +24,7 @@ def value_callback(ctx, value: str):
     if value is None:
         return None
     if not VALIDATIONS[ctx.params["key"]](value):
-        raise click.BadParameter(value)
+        raise click.BadParameter(f"Invalid value `{value}` for key `{ctx.params['key']}`")
     return value
 
 
