@@ -1,12 +1,11 @@
 import click
 
+from sym.cli.decorators import loses_interactivity, require_login, skip_analytics
 from sym.cli.helpers.global_options import GlobalOptions
 
 from ..actions.action_registry import ActionRegistry
 from ..data.request_data import RequestData
 from ..data.target_options import TargetOptions
-from ..decorators import loses_interactivity, require_login, skip_analytics
-from ..helpers.global_options import GlobalOptions
 from ..helpers.options import resource_argument
 from .sym import sym
 
