@@ -1,4 +1,4 @@
-import importlib.resources as pkg_resources
+import pkgutil
 from pathlib import Path
 from textwrap import dedent
 from typing import Dict, Optional, Tuple
@@ -57,7 +57,7 @@ def get_ansible_ssh_profile(client: SAMLClient):
 def aws_ssm_connection_plugin() -> Path:
     file = SymConfigFile(file_name=AWS_SSM_PATH, uid_scope=False)
     if not file.path.exists():
-        file.put(pkg_resources.read_text(connection, file.path.name))
+        file.put(pkgutil.get_data(connection.__name__, file.path.name).decode("utf-8"))
     return file.path
 
 
@@ -86,7 +86,7 @@ def create_ssh_bin(client):
     ssh_bin = proxy_client.subconfig(ANSIBLE_SSH_PATH)
 
     command = sym_subcommand(client, "ssh", '"$@"')
-    if (log_dir := client.options.log_dir) :
+    if log_dir := client.options.log_dir:
         command = Tee.tee_command(log_dir, command)
 
     # fmt: off
