@@ -12,11 +12,12 @@ from urllib.parse import urlsplit
 import click
 import dateutil.parser
 from policyuniverse.arn import ARN
+from sym.shared.cli.helpers import segment
+from sym.shared.cli.helpers.config import SymConfigFile
+from sym.shared.cli.helpers.keywords_to_options import keywords_to_options
+from sym.shared.cli.helpers.os import read_write_lock
 
-from sym.cli.helpers import segment, validations
-from sym.cli.helpers.config import SymConfigFile
-from sym.cli.helpers.keywords_to_options import keywords_to_options
-from sym.cli.helpers.os import read_write_lock
+from sym.cli.helpers import validations
 from sym.cli.helpers.params import Profile, get_aws_saml_url, get_profile
 
 
