@@ -3,9 +3,9 @@ from multiprocessing import Pool
 from uuid import UUID
 
 import pytest
+from sym.shared.cli.helpers.contexts import push_env
 
 from sym.cli.helpers.config import Config, SymConfigFile, init
-from sym.cli.helpers.contexts import push_env
 from sym.cli.tests.helpers.sandbox import Sandbox
 
 
